import { QueryMap } from './HTTPUtils';
export declare type HTTPHeaderFields = {
    [key: string]: string;
};
interface ContentType {
    mediaType: string;
    charset?: string;
}
export declare class HTTPHeader {
    header: HTTPHeaderFields;
    static fromXHR(xhr: XMLHttpRequest): HTTPHeaderFields;
    static fromMap(header: any): HTTPHeaderFields;
    constructor(initialHeaders?: any);
    getHeader(fieldName: string): string;
    setHeader(fieldName: string, fieldValue: string): void;
    exportHeader(xhr: XMLHttpRequest): void;
    getContentType(): ContentType | null;
}
export declare class TimeoutError extends Error {
    timeout: number;
    elapsed: number;
    xhr: XMLHttpRequest;
    constructor(timeout: number, elapsed: number, message: string, xhr: XMLHttpRequest);
    toString(): string;
}
export declare class GeneralError extends Error {
    xhr: XMLHttpRequest;
    constructor(message: string, xhr: XMLHttpRequest);
    toString(): string;
}
export declare class AbortError extends Error {
    xhr: XMLHttpRequest;
    constructor(message: string, xhr: XMLHttpRequest);
    toString(): string;
}
export interface RequestOptions {
    url: string;
    method: string;
    responseType: XMLHttpRequestResponseType;
    query?: QueryMap;
    timeout: number;
    header?: HTTPHeader;
    withCredentials?: boolean;
    data?: null | string | Array<number>;
    onCancel?: (callback: () => void) => void;
}
export declare type ResponseType = string;
export interface Response<T extends ResponseType> {
    status: number;
    response: T;
    responseType: XMLHttpRequestResponseType;
    header: HTTPHeader;
}
export interface StringResponse extends Response<string> {
    responseType: 'text';
    response: string;
}
export interface HTTPClientOptions {
    timeout?: number;
}
export default class HTTPClient {
    options?: HTTPClientOptions;
    constructor(options?: HTTPClientOptions);
    request<T extends ResponseType>(options: RequestOptions): Promise<StringResponse>;
}
export {};
